Dependencies & Plugins | AdminLTE 3 Documentation
Description: AdminLTE v3 Documentaion

Dependencies & Plugins | AdminLTE v3 Documentaion

# Dependencies & Plugins

#### Dependencies

AdminLTE depends on two main frameworks. The downloadable package contains both of these libraries, so you don’t have to manually download them.

- Bootstrap 4
- jQuery 3.3.1+
- Popper.js 1.14.7+
- All other plugins are listed below

#### Plugins

AdminLTE makes use of the following plugins. For documentation, updates or license information, please visit the provided links.

> Note! You need to load the js/css files of the plugin that you want to use. AdminLTE doesn’t load automatically all plugins, this would cause huge load times on every page load.

- #### Charts

- ChartJS
- Flot
- Sparkline

- #### Editors

- Summernote

- #### Form Elements

- Bootstrap Colorpicker
- Bootstrap Slider
- Date Range Picker
- iCheck Bootstrap
- Inputmask
- Ion.RangeSlider
- Select2
- Tempus Dominus
- Bootstrap4 Duallistbox
- bs-custom-file-input

- #### Icon Packs

- FontAwesome 5
- flag-icon-css

- #### Table Grids

- DataTables
- jsGrid

- #### Notifications

- SweetAlert2
- Toastr

- #### Others

- FastClick
- FullCalendar 4
- jQuery Knob
- jQuery UI
- jQuery Validation
- jQuery Mapael
- jQuery Vector Map
- Overlay Scrollbars
- Pace Progress
- FilterizR

- #### Plugin Dependencies

- jQuery Mousewheel
- Moment.js
- Raphaël
- pdfmake
- jszip